Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
func New ¶
New creates a Server and binds a listener on 127.0.0.1 at the port extracted from addr (default 7777). If that port is already in use, an ephemeral port is chosen automatically.
func (*Server) Addr ¶
Addr returns the address the server is actually listening on, e.g. "127.0.0.1:7777".
func (*Server) ListenAndServe ¶
Click to show internal directories.
Click to hide internal directories.